import 'package:flutter/material.dart';

/// Animation Types

enum AnimationType { normal, fadeIn }

/// Main Class
///

class RouteTransitions {
  final BuildContext context;
  final Widget child;
  final animation;
  final Duration duration;
  final bool replacement;

  RouteTransitions(
      {@required this.context,
      @required this.child,
      this.replacement = false,
      this.duration = const Duration(milliseconds: 300),
      this.animation = AnimationType.normal}) {
    //
    switch (this.animation) {
      case AnimationType.normal:
        _normalTransition();
        break;
      case AnimationType.fadeIn:
        _fadeInTransition();
        break;
    }
  }

  /// Normal Push
  void _pushPage(Route route) => Navigator.push(context, route);

  /// Push Replacement
  void _pushReplacementPage(Route route) =>
      Navigator.pushReplacement(context, route);

  /// Normal Transition
  void _normalTransition() => (replacement)
      ? Navigator.pushReplacement(
          context, MaterialPageRoute(builder: (_) => child))
      : Navigator.push(context, MaterialPageRoute(builder: (_) => child));

  /// Fade In Transition
  void _fadeInTransition() {
    final route = PageRouteBuilder(
        pageBuilder: (_, __, ___) => this.child,
        transitionDuration: duration,
        transitionsBuilder: (_, animation, __, child) {
          return FadeTransition(
            child: child,
            opacity: Tween<double>(begin: 0.0, end: 1.0).animate(
                CurvedAnimation(parent: animation, curve: Curves.easeOut)),
          );
        });

    (replacement) ? this._pushReplacementPage(route) : this._pushPage(route);
  }
}
